# Step 1 : TODO DigitalRecruiters : 

- Pull Request an example of a Profile.json in this repository 
- Pull Request an example of a Job.json in this repository
- Give an example of a GET request to retrieve jobs from DR : payload + endpoint
- Give an example of a POST request to upload a profile to DR : payload + endpoint
- Give an example of a PUT/PATCH/POST request to edit a job in DR : payload + endpoint
- Give an example of a PUT/PATCH/POST request to cancel a job in DR : payload + endpoint 

# Step 2 : TODO HrFlow.ai :
- Implement workflow pull_jobs_from_digitalrecruiters_into_hrflow.py
- Implement workflow push_profile_from_hrflow_into_digitalrecruiters.py
- Implement workflow edit_job_from_hrflow_into_digitalrecruiters.py
- Implement workflow cancel_job_from_hrflow_into_digitalrecruiters.py

